use Config;
use ExtUtils::Embed;
# $Id: Makefile.PL,v 1.1 1998/07/15 23:03:54 sinck Exp sinck $
# option definitions and defaults

%OPTDEF = ('prefix' => 1, 'htdocs' => 1, 'd' => 1, '?' => 1, 'help' => 1);
%DEFAULT = ('prefix' => '/usr/local/etc/httpd/cgi-bin/webgroove',
	'htdocs' => '/usr/local/etc/httpd/htdocs');

# process options

for ($ndx = 0; $ndx < @ARGV; $ndx++)
{
	if ($ARGV[$ndx] =~ /^\-+([^=]*)=?(.*)$/)
	{
		my $opt = lc($1);
		if ($OPTDEF{$opt})
		{
			$OPTS{$opt} = $2 || 1;
		}
		else
		{
			print "Invalid option: $ARGV[$ndx]\n";
		}
	}
	else
	{
		push @ARGS, $ARGV[$ndx];
	}
}

# process defaults

foreach (keys %DEFAULT)
{
	$OPTS{$_} = $DEFAULT{$_} if (!(exists $OPTS{$_}) and exists $DEFAULT{$_});
}

# print "ARGS: ", join(', ', @ARGS), "\n";
# print "OPTS: ", join(', ', map { "$_ = $OPTS{$_}" } keys %OPTS), "\n";

# display help

if ($OPTS{'?'} or $OPTS{'help'})
{
	print <<EOH;
Options:

--PREFIX=path   installation directory
--HTDOCS=path   web document root (examples installed in 'webgroove' under
                this directory)
--? or
--help          this help screen

Defaults:

EOH

	foreach (keys %DEFAULT)
	{
		print $_, " = ", $DEFAULT{$_}, "\n";
	}

	print "\nOptions are case insensitive and will work with either single or double dashes\n\n";
	exit 0;
}

# Extract Perl build info

%Global = (
	CCOPTS => ccopts(),
	LDOPTS => ldopts(0),
	CC => $Config{cc},
	PREFIX => $OPTS{prefix},
	HTDOCS => $OPTS{htdocs}
);

foreach (keys %Global) # trim leading whitespace
{
	$Global{$_} =~ s/^\s+//g;
}

$mode = $OPTS{d} ? "dev" : "rel";

# generate the makefiles
genmakefile("Makefile.tem", "Makefile");
genmakefile("wga/Makefile.$mode", "wga/msql/cgi/Makefile");
genmakefile("", "wga/mysql/cgi/Makefile");
genmakefile("wgc/Makefile.$mode", "wgc/Makefile");
genmakefile("", "wgc/eval/Makefile");

sub genmakefile
{
	my ($template, $makefile, $hashref) = @_;
	my $status = 1;
	my $ndx;
	my ($destdir) = ($makefile =~ /^(.*)[\\\/][^\\\/]*$/);

	# Load Makefile template (if any) and expand Globals

	if ($template)
	{
		print "Reading template: $template\n";

		if ($status = open (TEMPLATE, $template))
		{
		  	@Template = <TEMPLATE>;
			close TEMPLATE;
			for ($ndx = 0; $ndx < scalar(@Template); $ndx++)
			{
				foreach (keys %Global)
				{
					$Template[$ndx] =~ s/\{$_\}/$Global{$_}/g;
				}
			}
		}
		else
		{
			print "Error opening template: ", $template, "\n";
		}
	}

	# Create Makefile using the template

	return 0 if $destdir and !(-d $destdir);

	if ($status)
	{
		print "Creating $makefile\n";

		if ($status = open (MAKEFILE, ">$makefile"))
		{
			foreach $line (@Template)
			{
				if ($hashref)
				{
					foreach (keys %$hashref)
					{
						$line =~ s/\{$_\}/$$hashref{$_}/g;
					}
				}

				print MAKEFILE $line;
			}

			close MAKEFILE;
		}
		else
		{
			print "Error creating makefile: ", $makefile, "\n";
		}
	}

	return $status;
}


